<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Autorzy</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Tłumaczenie</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Podziękowania</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Oparty na bibliotekach QT odtwarzacz (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="67"/>
        <source>Version: %1</source>
        <translation>Wersja: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>Używa Qt %1 (kompilowany z Qt %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(c) %1-%2 Zespół programistyczny Qmmp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Input plugins:</source>
        <translation>Wtyczki wejściowe:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>Output plugins:</source>
        <translation>Wtyczki wyjściowe:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Visual plugins:</source>
        <translation>Wizualizacje:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="103"/>
        <source>Effect plugins:</source>
        <translation>Wtyczki efektów:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="112"/>
        <source>General plugins:</source>
        <translation>Wtyczki ogólne:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>Wipsz URL do dodania</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="43"/>
        <source>&amp;Add</source>
        <translation>Dod&amp;aj</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="50"/>
        <source>&amp;Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="124"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="314"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="319"/>
        <source>Filename</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="286"/>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="68"/>
        <location filename="../configdialog.cpp" line="287"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="67"/>
        <source>Track</source>
        <translation>Utwór</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="174"/>
        <source>Transports</source>
        <translation>Transporty</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="184"/>
        <source>Decoders</source>
        <translation>Dekodery</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="194"/>
        <source>Engines</source>
        <translation>Silniki</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="234"/>
        <source>Output</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>File Dialogs</source>
        <translation>Okno dialogowe</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="254"/>
        <source>User Interfaces</source>
        <translation>Interfejs użytkownika</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="288"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="289"/>
        <source>Track number</source>
        <translation>Numer utworu</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="290"/>
        <source>Two-digit track number</source>
        <translation>Dwuznakowy numer utworu</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="294"/>
        <source>Disc number</source>
        <translation>Numer albumu</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="298"/>
        <source>Condition</source>
        <translation>Warunek</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="308"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;Automatyczne&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="309"/>
        <source>Brazilian Portuguese</source>
        <translation>Brazylijski Portugalski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="310"/>
        <source>Chinese Simplified</source>
        <translation>Chiński Uproszczony</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="311"/>
        <source>Chinese Traditional</source>
        <translation>Chiński Tradycyjny</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="312"/>
        <source>Czech</source>
        <translation>Czeski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="313"/>
        <source>Dutch</source>
        <translation>Holenderski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="314"/>
        <source>English</source>
        <translation>Angielski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="315"/>
        <source>French</source>
        <translation>Francuski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="316"/>
        <source>Galician</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="317"/>
        <source>German</source>
        <translation>Niemiecki</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="318"/>
        <source>Hebrew</source>
        <translation>Hebrajski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="319"/>
        <source>Hungarian</source>
        <translation>Węgierski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="320"/>
        <source>Italian</source>
        <translation>Włoski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="321"/>
        <source>Japanese</source>
        <translation>Japoński</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="322"/>
        <source>Kazakh</source>
        <translation>Kazaski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="323"/>
        <source>Lithuanian</source>
        <translation>Litewski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="324"/>
        <source>Polish</source>
        <translation>Polski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="325"/>
        <source>Russian</source>
        <translation>Rosyjski</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="326"/>
        <source>Slovak</source>
        <translation>Słowacki</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="327"/>
        <source>Spanish</source>
        <translation>Hiszpański</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="328"/>
        <source>Turkish</source>
        <translation>Turecki</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="329"/>
        <source>Ukrainian</source>
        <translation>Ukraiński</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="291"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="293"/>
        <source>Composer</source>
        <translation>Kompozytor</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>File name</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="296"/>
        <source>File path</source>
        <translation>Lokalizacja</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="297"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="292"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Ustawienia Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="166"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>Metadane</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="135"/>
        <source>Load metadata from files</source>
        <translation>Załaduj metadane z pliku</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="156"/>
        <source>Title format:</source>
        <translation>Format tytułu:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="259"/>
        <source>Preferences</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="272"/>
        <source>Information</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Wtyczki</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Zaawansowane</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="818"/>
        <source>16-bit output</source>
        <translation>16-bitowe odtwarzanie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="214"/>
        <source>Visualization</source>
        <translation>Wizualizacje</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="204"/>
        <source>Effects</source>
        <translation>Efekty</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="757"/>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Directory Scanning Options</source>
        <translation>Opcje skanowania katalogów</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="182"/>
        <source>Restrict files to:</source>
        <translation>Ogranicz pliki do:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="205"/>
        <source>Miscellaneous</source>
        <translation>Różne</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="211"/>
        <source>Auto-save playlist when modified</source>
        <translation>Automatyczny zapis listy odtwarzania przy modyfikacji</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <source>Look and Feel</source>
        <translation>Wygląd i zachowanie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="337"/>
        <source>Language:</source>
        <translation>Język:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Add files from command line to this playlist:</source>
        <translation>Dodaj pliki z linii poleceń do listy odtwarzania:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>URL Dialog</source>
        <translation>Okno dialogowe URL</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="486"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>Automatycznie wklejaj URL ze schowka</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="627"/>
        <source>Replay Gain</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="633"/>
        <source>Replay Gain mode:</source>
        <translation>Tryb Replay Gain:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="650"/>
        <source>Preamp:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="682"/>
        <location filename="../forms/configdialog.ui" line="727"/>
        <source>dB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="695"/>
        <source>Default gain:</source>
        <translation>Domyślne wzmocnienie:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="747"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Użyj informacji peak by zapobiec &quot;klipnięciom&quot;</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="763"/>
        <source>Buffer size:</source>
        <translation>Rozmiar bufora:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="782"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="811"/>
        <source>Use software volume control</source>
        <translation>Użyj programowej regulacji głośności</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="410"/>
        <source>Cover Image Retrieve</source>
        <translation>Pobieranie okładek</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="416"/>
        <source>Use separate image files</source>
        <translation>Użyj oddzielnych obrazków</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="426"/>
        <source>Include files:</source>
        <translation>Użyj plików:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="192"/>
        <location filename="../forms/configdialog.ui" line="436"/>
        <source>Exclude files:</source>
        <translation>Wyłącz pliki:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="448"/>
        <source>Recursive search depth:</source>
        <translation>Głębokość rekursywnego przeszukiwania:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="373"/>
        <source>Playback</source>
        <translation>Odtwarzanie</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>Continue playback on startup</source>
        <translation>Wznów odtwarzanie po uruchomieniu programu</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="386"/>
        <source>Determine file type by content</source>
        <translation>Określ typ pliku po zawartości</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="525"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="537"/>
        <source>Enable proxy usage</source>
        <translation>Włącz proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="544"/>
        <source>Proxy host name:</source>
        <translation>Nazwa hosta proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="557"/>
        <source>Proxy port:</source>
        <translation>Port proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="570"/>
        <source>Use authentication with proxy</source>
        <translation>Użyj autoryzacji z proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="577"/>
        <source>Proxy user name:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="590"/>
        <source>Proxy password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="142"/>
        <source>Convert underscores to blanks</source>
        <translation>Konwertuj podkreślenia na spacje</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="149"/>
        <source>Convert %20 to blanks</source>
        <translation>Konwertuj sekwencje %20 na spacje</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="110"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="111"/>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="112"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="113"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="114"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="115"/>
        <source>Composer</source>
        <translation>Kompozytor</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="117"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="119"/>
        <source>Track</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="121"/>
        <source>Disc number</source>
        <translation>Numer płyty</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Szczegóły</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="42"/>
        <source>Open the directory containing this file</source>
        <translation>Otwórz katalog zawierający ten plik</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="45"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="59"/>
        <source>Summary</source>
        <translation>Informacje</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Skocz do utworu</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="92"/>
        <location filename="../jumptotrackdialog.cpp" line="145"/>
        <source>Queue</source>
        <translation>Kolejkuj</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Skocz do</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="59"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="60"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="61"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="90"/>
        <location filename="../jumptotrackdialog.cpp" line="143"/>
        <source>Unqueue</source>
        <translation>Wykolejkuj</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="108"/>
        <source>Unsupported playlist format</source>
        <translation>Niewspierane listy odtwarzania</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="164"/>
        <location filename="../playlistmanager.cpp" line="352"/>
        <source>Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="42"/>
        <source>Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="34"/>
        <source>Qt File Dialog</source>
        <translation>Okno dialogowe QT</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Artysta:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation>Kompozytor:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation>Gatunek:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="244"/>
        <source>Disc number:</source>
        <translation>Numer albumu:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="184"/>
        <location filename="../forms/tageditor.ui" line="222"/>
        <location filename="../forms/tageditor.ui" line="254"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="163"/>
        <source>Track:</source>
        <translation>Ścieżka:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="197"/>
        <source>Year:</source>
        <translation>Rok:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Edytor tagów</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="269"/>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="305"/>
        <source>Include selected tag in file</source>
        <translation>Dołącz wybrany tag do pliku</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Wstaw</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Edytor szablonów</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation>Numer utworu</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation>Dwucyfrowy numer utworu</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation>Kompozytor</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation>Numer płyty</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation>Ścieżka pliku</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation>Warunek</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="134"/>
        <source>All Supported Bitstreams</source>
        <translation>Wszystkie wspierane formaty</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="139"/>
        <source>Select one or more files to open</source>
        <translation>Wybierz jeden lub więcej plików do otwarcia</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="146"/>
        <source>Choose a directory</source>
        <translation>Wybierz katalog</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="162"/>
        <location filename="../uihelper.cpp" line="183"/>
        <source>Playlist Files</source>
        <translation>Pliki listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="164"/>
        <source>Open Playlist</source>
        <translation>Otwórz listę odtwarzania</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="184"/>
        <source>Save Playlist</source>
        <translation>Zapisz listę odtwarzania</translation>
    </message>
</context>
</TS>
